@@ -114,12 +114,17 @@ class ZObject (object):
 	def _show (self):
 		return '<ZObject\n\t' + '\n\t'.join (['%s:%s' % (x, str (getattr (self, x))) for x in dir (self) if not x.startswith ('_')]) + '\n>'
 
-class ZonePoint:
+class ZonePoint (object):
 	'A specific geographical point, or the INVALID_ZONEPOINT constant to represent no value.'
 	def __init__ (self, latitude, longitude, altitude):
-		self.latitude = latitude
-		self.longitude = longitude
-		self.altitude = altitude
+		# Don't trigger update_map when constructing new ZonePoints.
+		object.__setattr__ (self, 'latitude', latitude)
+		object.__setattr__ (self, 'longitude', longitude)
+		object.__setattr__ (self, 'altitude', altitude)
+	def __setattr__ (self, key, value):
+		object.__setattr__ (self, key, value)
+		if key in ('latitude', 'longitude'):
+			ZCartridge ()._cb.update_map ()
 	def __repr__ (self):
 		return 'ZonePoint (%f, %f, %f)' % (self.latitude, self.longitude, self.altitude)
 
